getnv <- function(  ) {

  return( vfenv$nv )

}
